import request from '@/utils/request';


// 查询调价申请详情
export function getPriceAdjustmentDetail (query) {
  return request({
    url: '/change/price/list/searchSupplyRequestInfo',
    method: 'post',
    params: query
  });
}



// 查询挂号调价详情
export function searchSupplyRequestByHealth (query) {
  return request({
    url: '/inventory-examine-page/searchSupplyRequestByHealth',
    method: 'post',
    params: query
  });
}

// 查询诊疗调价详情
export function searchSupplyRequestByActivity (query) {
  return request({
    url: '/inventory-examine-page/searchSupplyRequestByActivity',
    method: 'post',
    params: query
  });
}

// 查询耗材调价详情
export function searchSupplyRequestByDevice (query) {
  return request({
    url: '/inventory-examine-page/searchSupplyRequestByDevice',
    method: 'post',
    params: query
  });
}

// 查询药品调价详情
export function searchSupplyRequestByMed (query) {
  return request({
    url: '/inventory-examine-page/searchSupplyRequestByMed',
    method: 'post',
    params: query
  });
}





// 获取审核状态选项数据
export function getExamineStatusOptions() {
  return request({
    url: '/inventory-examine-page/init',
    method: 'get'
  });
}

// 驳回价格调整申请
export function rejectPriceAdjustment(busNo) {
  return request({
    url: '/inventory-examine-page/updateExamineByRejected',
    method: 'post',
    params: { busNo }
  });
}

// 审批通过价格调整申请
export function updateExamineByApproved(busNo) {
  return request({
    url: '/inventory-examine-page/updateExamineByApproved',
    method: 'post',
    params: { busNo }
  });
}

